@@ -214,7 +214,7 @@ class DescribeCallDetailRequest(AbstractModel):
         """
         :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位为s）例：1400353843_218695_1590065777。通过 DescribeRoomInformation（查询房间列表）接口获取（链接：https://cloud.tencent.com/document/product/647/44050）
         :type CommId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
@@ -313,7 +313,7 @@ class DescribeDetailEventRequest(AbstractModel):
         """
         :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位s）。通过 DescribeRoomInformation（查询房间列表）接口获取。（链接：https://cloud.tencent.com/document/product/647/44050）
         :type CommId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
@@ -592,6 +592,58 @@ class DescribeRealtimeScaleResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeRecordStatisticRequest(AbstractModel):
+    """DescribeRecordStatistic请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param StartTime: 查询开始日期，格式为YYYY-MM-DD。
+        :type StartTime: str
+        :param EndTime: 查询结束日期，格式为YYYY-MM-DD。
+单次查询统计区间最多不能超过31天。
+        :type EndTime: str
+        :param SdkAppId: 应用ID，可不传。传应用ID时返回的是该应用的用量，不传时返回多个应用的合计值。
+        :type SdkAppId: int
+        """
+        self.StartTime = None
+        self.EndTime = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.SdkAppId = params.get("SdkAppId")
+
+
+class DescribeRecordStatisticResponse(AbstractModel):
+    """DescribeRecordStatistic返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppIdUsages: 应用的用量信息数组。
+        :type SdkAppIdUsages: list of SdkAppIdRecordUsage
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.SdkAppIdUsages = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("SdkAppIdUsages") is not None:
+            self.SdkAppIdUsages = []
+            for item in params.get("SdkAppIdUsages"):
+                obj = SdkAppIdRecordUsage()
+                obj._deserialize(item)
+                self.SdkAppIdUsages.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeRoomInformationRequest(AbstractModel):
     """DescribeRoomInformation请求参数结构体
 
@@ -601,11 +653,11 @@ class DescribeRoomInformationRequest(AbstractModel):
         """
         :param SdkAppId: 用户sdkappid
         :type SdkAppId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
-        :param RoomId: 数字房间号
+        :param RoomId: 字符串房间号
         :type RoomId: str
         :param PageNumber: 分页index，从0开始（PageNumber和PageSize 其中一个不填均默认返回10条数据）
         :type PageNumber: str
@@ -636,7 +688,7 @@ class DescribeRoomInformationResponse(AbstractModel):
 
     def __init__(self):
         """
-        :param Total: 返回的数据总条数
+        :param Total: 返回当页数据总数
         :type Total: int
         :param RoomList: 房间信息列表
         :type RoomList: list of RoomState
@@ -659,6 +711,110 @@ class DescribeRoomInformationResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DescribeTrtcInteractiveTimeRequest(AbstractModel):
+    """DescribeTrtcInteractiveTime请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param StartTime: 查询开始时间，格式为YYYY-MM-DD。
+        :type StartTime: str
+        :param EndTime: 查询结束时间，格式为YYYY-MM-DD。
+单次查询统计区间最多不能超过31天。
+        :type EndTime: str
+        :param SdkAppId: 应用ID，可不传。传应用ID时返回的是该应用的用量，不传时返回所有应用的合计值。
+        :type SdkAppId: int
+        """
+        self.StartTime = None
+        self.EndTime = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.SdkAppId = params.get("SdkAppId")
+
+
+class DescribeTrtcInteractiveTimeResponse(AbstractModel):
+    """DescribeTrtcInteractiveTime返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Usages: 应用的用量信息数组。
+        :type Usages: list of OneSdkAppIdUsagesInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Usages = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Usages") is not None:
+            self.Usages = []
+            for item in params.get("Usages"):
+                obj = OneSdkAppIdUsagesInfo()
+                obj._deserialize(item)
+                self.Usages.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
+class DescribeTrtcMcuTranscodeTimeRequest(AbstractModel):
+    """DescribeTrtcMcuTranscodeTime请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param StartTime: 查询开始时间，格式为YYYY-MM-DD。
+        :type StartTime: str
+        :param EndTime: 查询结束时间，格式为YYYY-MM-DD。
+单次查询统计区间最多不能超过31天。
+        :type EndTime: str
+        :param SdkAppId: 应用ID，可不传。传应用ID时返回的是该应用的用量，不传时返回多个应用的合计值。
+        :type SdkAppId: int
+        """
+        self.StartTime = None
+        self.EndTime = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.StartTime = params.get("StartTime")
+        self.EndTime = params.get("EndTime")
+        self.SdkAppId = params.get("SdkAppId")
+
+
+class DescribeTrtcMcuTranscodeTimeResponse(AbstractModel):
+    """DescribeTrtcMcuTranscodeTime返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param Usages: 应用的用量信息数组。
+        :type Usages: list of OneSdkAppIdTranscodeTimeUsagesInfo
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.Usages = None
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        if params.get("Usages") is not None:
+            self.Usages = []
+            for item in params.get("Usages"):
+                obj = OneSdkAppIdTranscodeTimeUsagesInfo()
+                obj._deserialize(item)
+                self.Usages.append(obj)
+        self.RequestId = params.get("RequestId")
+
+
 class DescribeUserInformationRequest(AbstractModel):
     """DescribeUserInformation请求参数结构体
 
@@ -668,7 +824,7 @@ class DescribeUserInformationRequest(AbstractModel):
         """
         :param CommId: 通话 ID（唯一标识一次通话）： sdkappid_roomgString（房间号_createTime（房间创建时间，unix时间戳，单位为s）例：1400353843_218695_1590065777。通过 DescribeRoomInformation（查询房间列表）接口获取（链接：https://cloud.tencent.com/document/product/647/44050）
         :type CommId: str
-        :param StartTime: 查询开始时间，5天内。本地unix时间戳（1588031999s）
+        :param StartTime: 查询开始时间，14天内。本地unix时间戳（1588031999s）
         :type StartTime: int
         :param EndTime: 查询结束时间，本地unix时间戳（1588031999s）
         :type EndTime: int
@@ -731,6 +887,44 @@ class DescribeUserInformationResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class DismissRoomByStrRoomIdRequest(AbstractModel):
+    """DismissRoomByStrRoomId请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: TRTC的SDKAppId。
+        :type SdkAppId: int
+        :param RoomId: 房间号。
+        :type RoomId: str
+        """
+        self.SdkAppId = None
+        self.RoomId = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.RoomId = params.get("RoomId")
+
+
+class DismissRoomByStrRoomIdResponse(AbstractModel):
+    """DismissRoomByStrRoomId返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class DismissRoomRequest(AbstractModel):
     """DismissRoom请求参数结构体
 
@@ -906,6 +1100,10 @@ class LayoutParams(AbstractModel):
         :type MixVideoUids: list of str
         :param PresetLayoutConfig: 自定义模板中有效，指定用户视频在混合画面中的位置。
         :type PresetLayoutConfig: list of PresetLayoutConfig
+        :param PlaceHolderMode: 自定义模板中有效，设置为1时代表启用占位图功能，0时代表不启用占位图功能，默认为0。启用占位图功能时，在预设位置的用户没有上行视频时可显示对应的占位图。
+        :type PlaceHolderMode: int
+        :param PureAudioHoldPlaceMode: 悬浮模板、九宫格、屏幕分享模板生效，用于控制纯音频上行是否占用画面布局位置。设置为0是代表后台默认处理方式，悬浮小画面占布局位置，九宫格画面占布局位置、屏幕分享小画面不占布局位置；设置为1时代表纯音频上行占布局位置；设置为2时代表纯音频上行不占布局位置。默认为0。
+        :type PureAudioHoldPlaceMode: int
         """
         self.Template = None
         self.MainVideoUserId = None
@@ -914,6 +1112,8 @@ class LayoutParams(AbstractModel):
         self.MainVideoRightAlign = None
         self.MixVideoUids = None
         self.PresetLayoutConfig = None
+        self.PlaceHolderMode = None
+        self.PureAudioHoldPlaceMode = None
 
 
     def _deserialize(self, params):
@@ -931,6 +1131,68 @@ class LayoutParams(AbstractModel):
                 obj = PresetLayoutConfig()
                 obj._deserialize(item)
                 self.PresetLayoutConfig.append(obj)
+        self.PlaceHolderMode = params.get("PlaceHolderMode")
+        self.PureAudioHoldPlaceMode = params.get("PureAudioHoldPlaceMode")
+
+
+class OneSdkAppIdTranscodeTimeUsagesInfo(AbstractModel):
+    """旁路转码时长的查询结果
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppIdTranscodeTimeUsages: 旁路转码时长查询结果数组
+        :type SdkAppIdTranscodeTimeUsages: list of SdkAppIdTrtcMcuTranscodeTimeUsage
+        :param TotalNum: 查询记录数量
+        :type TotalNum: int
+        :param SdkAppId: 所查询的应用ID，可能值为:1-应用的应用ID，2-total，显示为total则表示查询的是所有应用的用量合计值。
+        :type SdkAppId: str
+        """
+        self.SdkAppIdTranscodeTimeUsages = None
+        self.TotalNum = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        if params.get("SdkAppIdTranscodeTimeUsages") is not None:
+            self.SdkAppIdTranscodeTimeUsages = []
+            for item in params.get("SdkAppIdTranscodeTimeUsages"):
+                obj = SdkAppIdTrtcMcuTranscodeTimeUsage()
+                obj._deserialize(item)
+                self.SdkAppIdTranscodeTimeUsages.append(obj)
+        self.TotalNum = params.get("TotalNum")
+        self.SdkAppId = params.get("SdkAppId")
+
+
+class OneSdkAppIdUsagesInfo(AbstractModel):
+    """单个SdkAppId的音视频互动计费时长用量数组和数组长度。
+
+    """
+
+    def __init__(self):
+        """
+        :param TotalNum: 该 SdkAppId 对应的用量记录数长度
+        :type TotalNum: int
+        :param SdkAppIdTrtcTimeUsages: 用量数组
+        :type SdkAppIdTrtcTimeUsages: list of SdkAppIdTrtcUsage
+        :param SdkAppId: 应用ID
+        :type SdkAppId: str
+        """
+        self.TotalNum = None
+        self.SdkAppIdTrtcTimeUsages = None
+        self.SdkAppId = None
+
+
+    def _deserialize(self, params):
+        self.TotalNum = params.get("TotalNum")
+        if params.get("SdkAppIdTrtcTimeUsages") is not None:
+            self.SdkAppIdTrtcTimeUsages = []
+            for item in params.get("SdkAppIdTrtcTimeUsages"):
+                obj = SdkAppIdTrtcUsage()
+                obj._deserialize(item)
+                self.SdkAppIdTrtcTimeUsages.append(obj)
+        self.SdkAppId = params.get("SdkAppId")
 
 
 class OutputParams(AbstractModel):
@@ -944,7 +1206,7 @@ class OutputParams(AbstractModel):
         :type StreamId: str
         :param PureAudioStream: 取值范围[0,1]， 填0：直播流为音视频(默认); 填1：直播流为纯音频
         :type PureAudioStream: int
-        :param RecordId: 自定义录制文件名
+        :param RecordId: 自定义录制文件名。请先在实时音视频控制台开通录制功能，https://cloud.tencent.com/document/product/647/50768
         :type RecordId: str
         :param RecordAudioOnly: 取值范围[0,1]，填0无实际含义; 填1：指定录制文件格式为mp3
         :type RecordAudioOnly: int
@@ -983,8 +1245,12 @@ class PresetLayoutConfig(AbstractModel):
         :type LocationY: int
         :param ZOrder: 该画面在输出时的层级，单位为像素值，不填默认为0。
         :type ZOrder: int
-        :param RenderMode: 该画面在输出时的显示模式：0为裁剪，1为缩放，不填默认为0。
+        :param RenderMode: 该画面在输出时的显示模式：0为裁剪，1为缩放，2为缩放并显示黑底。不填默认为0。
         :type RenderMode: int
+        :param MixInputType: 该当前位置用户混入的流类型：0为混入音视频，1为只混入视频，2为只混入音频。默认为0，建议配合指定用户ID使用。
+        :type MixInputType: int
+        :param PlaceImageId: 占位图ID。启用占位图功能时，在当前位置的用户没有上行视频时显示占位图。占位图在实时音视频控制台上传并生成，https://cloud.tencent.com/document/product/647/50769
+        :type PlaceImageId: int
         """
         self.UserId = None
         self.StreamType = None
@@ -994,6 +1260,8 @@ class PresetLayoutConfig(AbstractModel):
         self.LocationY = None
         self.ZOrder = None
         self.RenderMode = None
+        self.MixInputType = None
+        self.PlaceImageId = None
 
 
     def _deserialize(self, params):
@@ -1005,6 +1273,29 @@ class PresetLayoutConfig(AbstractModel):
         self.LocationY = params.get("LocationY")
         self.ZOrder = params.get("ZOrder")
         self.RenderMode = params.get("RenderMode")
+        self.MixInputType = params.get("MixInputType")
+        self.PlaceImageId = params.get("PlaceImageId")
+
+
+class PublishCdnParams(AbstractModel):
+    """第三方CDN转推参数
+
+    """
+
+    def __init__(self):
+        """
+        :param BizId: 腾讯云直播BizId。
+        :type BizId: int
+        :param PublishCdnUrls: 第三方CDN转推的目的地址，同时只支持转推一个第三方CDN地址。
+        :type PublishCdnUrls: list of str
+        """
+        self.BizId = None
+        self.PublishCdnUrls = None
+
+
+    def _deserialize(self, params):
+        self.BizId = params.get("BizId")
+        self.PublishCdnUrls = params.get("PublishCdnUrls")
 
 
 class QualityData(AbstractModel):
@@ -1069,6 +1360,81 @@ class RealtimeData(AbstractModel):
         self.DataType = params.get("DataType")
 
 
+class RecordUsage(AbstractModel):
+    """录制的使用信息。
+
+    """
+
+    def __init__(self):
+        """
+        :param TimeKey: 本组数据对应的时间点，格式如:2020-09-07或2020-09-07 00:05:05。
+        :type TimeKey: str
+        :param Class1VideoTime: 视频时长-标清SD，单位：秒。
+        :type Class1VideoTime: int
+        :param Class2VideoTime: 视频时长-高清HD，单位：秒。
+        :type Class2VideoTime: int
+        :param Class3VideoTime: 视频时长-超清HD，单位：秒。
+        :type Class3VideoTime: int
+        :param AudioTime: 语音时长，单位：秒。
+        :type AudioTime: int
+        """
+        self.TimeKey = None
+        self.Class1VideoTime = None
+        self.Class2VideoTime = None
+        self.Class3VideoTime = None
+        self.AudioTime = None
+
+
+    def _deserialize(self, params):
+        self.TimeKey = params.get("TimeKey")
+        self.Class1VideoTime = params.get("Class1VideoTime")
+        self.Class2VideoTime = params.get("Class2VideoTime")
+        self.Class3VideoTime = params.get("Class3VideoTime")
+        self.AudioTime = params.get("AudioTime")
+
+
+class RemoveUserByStrRoomIdRequest(AbstractModel):
+    """RemoveUserByStrRoomId请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: TRTC的SDKAppId。
+        :type SdkAppId: int
+        :param RoomId: 房间号。
+        :type RoomId: str
+        :param UserIds: 要移出的用户列表，最多10个。
+        :type UserIds: list of str
+        """
+        self.SdkAppId = None
+        self.RoomId = None
+        self.UserIds = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.RoomId = params.get("RoomId")
+        self.UserIds = params.get("UserIds")
+
+
+class RemoveUserByStrRoomIdResponse(AbstractModel):
+    """RemoveUserByStrRoomId返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class RemoveUserRequest(AbstractModel):
     """RemoveUser请求参数结构体
 
@@ -1180,6 +1546,105 @@ class ScaleInfomation(AbstractModel):
         self.RoomNumbers = params.get("RoomNumbers")
 
 
+class SdkAppIdRecordUsage(AbstractModel):
+    """SdkAppId级别录制时长数据。
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: SdkAppId的值。
+        :type SdkAppId: str
+        :param Usages: 统计的时间点数据。
+        :type Usages: list of RecordUsage
+        """
+        self.SdkAppId = None
+        self.Usages = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        if params.get("Usages") is not None:
+            self.Usages = []
+            for item in params.get("Usages"):
+                obj = RecordUsage()
+                obj._deserialize(item)
+                self.Usages.append(obj)
+
+
+class SdkAppIdTrtcMcuTranscodeTimeUsage(AbstractModel):
+    """查询旁路转码计费时长。
+    查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
+
+    """
+
+    def __init__(self):
+        """
+        :param TimeKey: 本组数据对应的时间点，格式如：2020-09-07或2020-09-07 00:05:05。
+        :type TimeKey: str
+        :param AudioTime: 语音时长，单位：秒。
+        :type AudioTime: int
+        :param VideoTimeSd: 视频时长-标清SD，单位：秒。
+        :type VideoTimeSd: int
+        :param VideoTimeHd: 视频时长-高清HD，单位：秒。
+        :type VideoTimeHd: int
+        :param VideoTimeFhd: 视频时长-全高清FHD，单位：秒。
+        :type VideoTimeFhd: int
+        """
+        self.TimeKey = None
+        self.AudioTime = None
+        self.VideoTimeSd = None
+        self.VideoTimeHd = None
+        self.VideoTimeFhd = None
+
+
+    def _deserialize(self, params):
+        self.TimeKey = params.get("TimeKey")
+        self.AudioTime = params.get("AudioTime")
+        self.VideoTimeSd = params.get("VideoTimeSd")
+        self.VideoTimeHd = params.get("VideoTimeHd")
+        self.VideoTimeFhd = params.get("VideoTimeFhd")
+
+
+class SdkAppIdTrtcUsage(AbstractModel):
+    """查询音视频互动时长的输出数据。
+    查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
+
+    """
+
+    def __init__(self):
+        """
+        :param TimeKey: 本组数据对应的时间点，格式如：2020-09-07或2020-09-07 00:05:05。
+        :type TimeKey: str
+        :param AudioTime: 语音时长，单位：秒。
+        :type AudioTime: int
+        :param AudioVideoTime: 音视频时长，单位：秒。
+2019年10月11日前注册，没有变更为 [新计费模式](https://cloud.tencent.com/document/product/647/17157) 的用户才会返回此值。
+        :type AudioVideoTime: int
+        :param VideoTimeSd: 视频时长-标清SD，单位：秒。
+        :type VideoTimeSd: int
+        :param VideoTimeHd: 视频时长-高清HD，单位：秒。
+        :type VideoTimeHd: int
+        :param VideoTimeHdp: 视频时长-超清HD，单位：秒。
+        :type VideoTimeHdp: int
+        """
+        self.TimeKey = None
+        self.AudioTime = None
+        self.AudioVideoTime = None
+        self.VideoTimeSd = None
+        self.VideoTimeHd = None
+        self.VideoTimeHdp = None
+
+
+    def _deserialize(self, params):
+        self.TimeKey = params.get("TimeKey")
+        self.AudioTime = params.get("AudioTime")
+        self.AudioVideoTime = params.get("AudioVideoTime")
+        self.VideoTimeSd = params.get("VideoTimeSd")
+        self.VideoTimeHd = params.get("VideoTimeHd")
+        self.VideoTimeHdp = params.get("VideoTimeHdp")
+
+
 class SmallVideoLayoutParams(AbstractModel):
     """画中画模板中有效，代表小画面的布局参数
 
@@ -1217,6 +1682,68 @@ class SmallVideoLayoutParams(AbstractModel):
         self.LocationY = params.get("LocationY")
 
 
+class StartMCUMixTranscodeByStrRoomIdRequest(AbstractModel):
+    """StartMCUMixTranscodeByStrRoomId请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: TRTC的SDKAppId。
+        :type SdkAppId: int
+        :param StrRoomId: 字符串房间号。
+        :type StrRoomId: str
+        :param OutputParams: 混流输出控制参数。
+        :type OutputParams: :class:`tencentcloud.trtc.v20190722.models.OutputParams`
+        :param EncodeParams: 混流输出编码参数。
+        :type EncodeParams: :class:`tencentcloud.trtc.v20190722.models.EncodeParams`
+        :param LayoutParams: 混流输出布局参数。
+        :type LayoutParams: :class:`tencentcloud.trtc.v20190722.models.LayoutParams`
+        :param PublishCdnParams: 第三方CDN转推参数。
+        :type PublishCdnParams: :class:`tencentcloud.trtc.v20190722.models.PublishCdnParams`
+        """
+        self.SdkAppId = None
+        self.StrRoomId = None
+        self.OutputParams = None
+        self.EncodeParams = None
+        self.LayoutParams = None
+        self.PublishCdnParams = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.StrRoomId = params.get("StrRoomId")
+        if params.get("OutputParams") is not None:
+            self.OutputParams = OutputParams()
+            self.OutputParams._deserialize(params.get("OutputParams"))
+        if params.get("EncodeParams") is not None:
+            self.EncodeParams = EncodeParams()
+            self.EncodeParams._deserialize(params.get("EncodeParams"))
+        if params.get("LayoutParams") is not None:
+            self.LayoutParams = LayoutParams()
+            self.LayoutParams._deserialize(params.get("LayoutParams"))
+        if params.get("PublishCdnParams") is not None:
+            self.PublishCdnParams = PublishCdnParams()
+            self.PublishCdnParams._deserialize(params.get("PublishCdnParams"))
+
+
+class StartMCUMixTranscodeByStrRoomIdResponse(AbstractModel):
+    """StartMCUMixTranscodeByStrRoomId返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class StartMCUMixTranscodeRequest(AbstractModel):
     """StartMCUMixTranscode请求参数结构体
 
@@ -1234,12 +1761,15 @@ class StartMCUMixTranscodeRequest(AbstractModel):
         :type EncodeParams: :class:`tencentcloud.trtc.v20190722.models.EncodeParams`
         :param LayoutParams: 混流输出布局参数。
         :type LayoutParams: :class:`tencentcloud.trtc.v20190722.models.LayoutParams`
+        :param PublishCdnParams: 第三方CDN转推参数。
+        :type PublishCdnParams: :class:`tencentcloud.trtc.v20190722.models.PublishCdnParams`
         """
         self.SdkAppId = None
         self.RoomId = None
         self.OutputParams = None
         self.EncodeParams = None
         self.LayoutParams = None
+        self.PublishCdnParams = None
 
 
     def _deserialize(self, params):
@@ -1254,6 +1784,9 @@ class StartMCUMixTranscodeRequest(AbstractModel):
         if params.get("LayoutParams") is not None:
             self.LayoutParams = LayoutParams()
             self.LayoutParams._deserialize(params.get("LayoutParams"))
+        if params.get("PublishCdnParams") is not None:
+            self.PublishCdnParams = PublishCdnParams()
+            self.PublishCdnParams._deserialize(params.get("PublishCdnParams"))
 
 
 class StartMCUMixTranscodeResponse(AbstractModel):
@@ -1273,6 +1806,44 @@ class StartMCUMixTranscodeResponse(AbstractModel):
         self.RequestId = params.get("RequestId")
 
 
+class StopMCUMixTranscodeByStrRoomIdRequest(AbstractModel):
+    """StopMCUMixTranscodeByStrRoomId请求参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param SdkAppId: TRTC的SDKAppId。
+        :type SdkAppId: int
+        :param StrRoomId: 字符串房间号。
+        :type StrRoomId: str
+        """
+        self.SdkAppId = None
+        self.StrRoomId = None
+
+
+    def _deserialize(self, params):
+        self.SdkAppId = params.get("SdkAppId")
+        self.StrRoomId = params.get("StrRoomId")
+
+
+class StopMCUMixTranscodeByStrRoomIdResponse(AbstractModel):
+    """StopMCUMixTranscodeByStrRoomId返回参数结构体
+
+    """
+
+    def __init__(self):
+        """
+        :param RequestId: 唯一请求 ID，每次请求都会返回。定位问题时需要提供该次请求的 RequestId。
+        :type RequestId: str
+        """
+        self.RequestId = None
+
+
+    def _deserialize(self, params):
+        self.RequestId = params.get("RequestId")
+
+
 class StopMCUMixTranscodeRequest(AbstractModel):
     """StopMCUMixTranscode请求参数结构体
 
