@@ -23,6 +23,7 @@ from tencentcloud.trtc.v20190722 import models
 class TrtcClient(AbstractClient):
     _apiVersion = '2019-07-22'
     _endpoint = 'trtc.tencentcloudapi.com'
+    _service = 'trtc'
 
 
     def CreateTroubleInfo(self, request):
@@ -54,7 +55,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeAbnormalEvent(self, request):
-        """查询SDKAppID下用户的异常体验事件，返回异常体验ID与可能产生异常体验的原因。可查询5天内数据，查询起止时间不超过1个小时。支持跨天查询。异常体验ID映射见：https://cloud.tencent.com/document/product/647/44916
+        """查询SDKAppID下用户的异常体验事件，返回异常体验ID与可能产生异常体验的原因。可查询15天内数据，查询起止时间不超过1个小时。支持跨天查询。异常体验ID映射见：https://cloud.tencent.com/document/product/647/44916
 
         :param request: Request instance for DescribeAbnormalEvent.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeAbnormalEventRequest`
@@ -83,6 +84,7 @@ class TrtcClient(AbstractClient):
 
     def DescribeCallDetail(self, request):
         """查询指定时间内的用户列表及用户通话质量数据，可查询14天内数据。DataType 不为null，查询实时数据时，查询起止时间不超过1个小时，每次查询用户不超过6个，支持跨天查询。DataType，UserIds为null时，默认查询6个用户，同时支持每页查询100以内用户个数（PageSize不超过100）。接口用于查询质量问题，不推荐作为计费使用。
+        注意：不建议依赖接口做实时类业务逻辑处理
 
         :param request: Request instance for DescribeCallDetail.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeCallDetailRequest`
@@ -166,7 +168,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeRealtimeNetwork(self, request):
-        """查询sdkappid维度下实时网络状态，包括上行丢包与下行丢包。可查询24小时内数据，查询起止时间不超过1个小时。
+        """查询sdkappid维度下每分钟实时网络状态，包括上行丢包与下行丢包。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
 
         :param request: Request instance for DescribeRealtimeNetwork.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeNetworkRequest`
@@ -194,7 +196,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeRealtimeQuality(self, request):
-        """查询sdkappid维度下实时质量数据，包括：进房成功率，首帧秒开率，音频卡顿率，视频卡顿率。可查询24小时内数据，查询起止时间不超过1个小时。
+        """查询sdkappid维度下每分钟实时质量数据，包括：进房成功率，首帧秒开率，音频卡顿率，视频卡顿率。可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
 
         :param request: Request instance for DescribeRealtimeQuality.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeQualityRequest`
@@ -222,7 +224,7 @@ class TrtcClient(AbstractClient):
 
 
     def DescribeRealtimeScale(self, request):
-        """查询sdkappid维度下实时规模，可查询24小时内数据，查询起止时间不超过1个小时。
+        """查询sdkappid维度下每分钟实时规模，可查询24小时内数据，查询起止时间不低于1分钟，不超过1个小时。
 
         :param request: Request instance for DescribeRealtimeScale.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRealtimeScaleRequest`
@@ -249,8 +251,42 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeRecordStatistic(self, request):
+        """查询云端录制计费时长。
+
+        - 查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
+        - 单次查询统计区间最多不能超过31天。
+        - 若查询当天用量，由于统计延迟等原因，返回数据可能不够准确。
+        - 日结后付费将于次日上午推送账单，建议次日上午9点以后再来查询前一天的用量。
+
+        :param request: Request instance for DescribeRecordStatistic.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRecordStatisticRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeRecordStatisticResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeRecordStatistic", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeRecordStatisticResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeRoomInformation(self, request):
         """查询sdkappid下的房间列表。默认返回10条通话，一次最多返回100条通话。可查询14天内的数据。
+        注意：不建议依赖接口做实时类业务逻辑处理
 
         :param request: Request instance for DescribeRoomInformation.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeRoomInformationRequest`
@@ -277,8 +313,73 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DescribeTrtcInteractiveTime(self, request):
+        """查询音视频互动计费时长。
+        - 查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
+        - 单次查询统计区间最多不能超过31天。
+        - 若查询当天用量，由于统计延迟等原因，返回数据可能不够准确。
+        - 日结后付费将于次日上午推送账单，建议次日上午9点以后再来查询前一天的用量。
+
+        :param request: Request instance for DescribeTrtcInteractiveTime.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcInteractiveTimeRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcInteractiveTimeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeTrtcInteractiveTime", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeTrtcInteractiveTimeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def DescribeTrtcMcuTranscodeTime(self, request):
+        """查询旁路转码计费时长。
+        - 查询时间小于等于1天时，返回每5分钟粒度的数据；查询时间大于1天时，返回按天汇总的数据。
+        - 单次查询统计区间最多不能超过31天。
+        - 若查询当天用量，由于统计延迟等原因，返回数据可能不够准确。
+        - 日结后付费将于次日上午推送账单，建议次日上午9点以后再来查询前一天的用量。
+
+        :param request: Request instance for DescribeTrtcMcuTranscodeTime.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcMcuTranscodeTimeRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DescribeTrtcMcuTranscodeTimeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DescribeTrtcMcuTranscodeTime", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DescribeTrtcMcuTranscodeTimeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def DescribeUserInformation(self, request):
-        """查询指定时间内的用户列表，可查询14天内数据。默认每页查询6个用户，支持每页最大查询100个用户PageSize不超过100）。
+        """查询指定时间内的用户列表，可查询14天内数据，查询起止时间不超过4小时。默认每页查询6个用户，支持每页最大查询100个用户PageSize不超过100）。
+        注意：不建议依赖接口做实时类业务逻辑处理
 
         :param request: Request instance for DescribeUserInformation.
         :type request: :class:`tencentcloud.trtc.v20190722.models.DescribeUserInformationRequest`
@@ -333,6 +434,34 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def DismissRoomByStrRoomId(self, request):
+        """接口说明：把房间所有用户从房间移出，解散房间。支持所有平台，Android、iOS、Windows 和 macOS 需升级到 TRTC SDK 6.6及以上版本。
+
+        :param request: Request instance for DismissRoomByStrRoomId.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.DismissRoomByStrRoomIdRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.DismissRoomByStrRoomIdResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("DismissRoomByStrRoomId", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.DismissRoomByStrRoomIdResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def RemoveUser(self, request):
         """接口说明：将用户从房间移出，适用于主播/房主/管理员踢人等场景。支持所有平台，Android、iOS、Windows 和 macOS 需升级到 TRTC SDK 6.6及以上版本。
 
@@ -361,9 +490,82 @@ class TrtcClient(AbstractClient):
                 raise TencentCloudSDKException(e.message, e.message)
 
 
+    def RemoveUserByStrRoomId(self, request):
+        """接口说明：将用户从房间移出，适用于主播/房主/管理员踢人等场景。支持所有平台，Android、iOS、Windows 和 macOS 需升级到 TRTC SDK 6.6及以上版本。
+
+        :param request: Request instance for RemoveUserByStrRoomId.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.RemoveUserByStrRoomIdRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.RemoveUserByStrRoomIdResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("RemoveUserByStrRoomId", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.RemoveUserByStrRoomIdResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
     def StartMCUMixTranscode(self, request):
         """接口说明：启动云端混流，并指定混流画面中各路画面的布局位置。
 
+        TRTC 的一个房间中可能会同时存在多路音视频流，您可以通过此 API 接口，通知腾讯云服务端将多路视频画面合成一路，并指定每一路画面的位置，同时将多路声音进行混音，最终形成一路音视频流，以便用于录制和直播观看。房间销毁后混流自动结束。
+
+        您可以通过此接口实现如下目标：
+        - 设置最终直播流的画质和音质，包括视频分辨率、视频码率、视频帧率、以及声音质量等。
+        - 设置各路画面的位置和布局，您只需要在启动时设置一次，排版引擎会自动完成后续的画面排布。
+        - 设置录制文件名，用于二次回放。
+        - 设置 CDN 直播流 ID，用于在 CDN 进行直播观看。
+
+        目前已经支持了如下几种布局模板：
+        - 悬浮模板：第一个进入房间的用户的视频画面会铺满整个屏幕，其他用户的视频画面从左下角依次水平排列，显示为小画面，最多4行，每行4个，小画面悬浮于大画面之上。最多支持1个大画面和15个小画面，如果用户只发送音频，仍然会占用画面位置。
+        - 九宫格模板：所有用户的视频画面大小一致，平分整个屏幕，人数越多，每个画面的尺寸越小。最多支持16个画面，如果用户只发送音频，仍然会占用画面位置。
+        - 屏幕分享模板：适合视频会议和在线教育场景的布局，屏幕分享（或者主讲的摄像头）始终占据屏幕左侧的大画面位置，其他用户依次垂直排列于右侧，最多两列，每列最多8个小画面。最多支持1个大画面和15个小画面。若上行分辨率宽高比与画面输出宽高比不一致时，左侧大画面为了保持内容的完整性采用缩放方式处理，右侧小画面采用裁剪方式处理。
+        - 画中画模板：适用于混合大小两路视频画面和其他用户混音，或者混合一路大画面和其他用户混音的场景。小画面悬浮于大画面之上，可以指定大小画面的用户以及小画面的显示位置，最多支持2个画面。
+        - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。预设位置填满时，不再混合其他用户的画面和声音。自定义模板启用占位图功能时（LayoutParams中的PlaceHolderMode设置成1），在预设位置的用户没有上行视频时可显示对应的占位图（PlaceImageId）。
+
+        注意：2020年1月9号及以后创建的应用才能直接调用此接口。2020年1月9日之前创建的应用默认使用云直播的云端混流，如需切换至MCU混流，请[提交工单](https://console.cloud.tencent.com/workorder/category)寻求帮助。
+
+        :param request: Request instance for StartMCUMixTranscode.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.StartMCUMixTranscodeRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.StartMCUMixTranscodeResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("StartMCUMixTranscode", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StartMCUMixTranscodeResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StartMCUMixTranscodeByStrRoomId(self, request):
+        """接口说明：启动云端混流，并指定混流画面中各路画面的布局位置。
+
         TRTC 的一个房间中可能会同时存在多路音视频流，您可以通过此 API 接口，通知腾讯云服务端将多路视频画面合成一路，并指定每一路画面的位置，同时将多路声音进行混音，最终形成一路音视频流，以便用于录制和直播观看。
 
         您可以通过此接口实现如下目标：
@@ -377,21 +579,21 @@ class TrtcClient(AbstractClient):
         - 九宫格模板：所有用户的视频画面大小一致，平分整个屏幕，人数越多，每个画面的尺寸越小。最多支持16个画面，如果用户只发送音频，仍然会占用画面位置。
         - 屏幕分享模板：适合视频会议和在线教育场景的布局，屏幕分享（或者主讲的摄像头）始终占据屏幕左侧的大画面位置，其他用户依次垂直排列于右侧，最多两列，每列最多8个小画面。最多支持1个大画面和15个小画面。若上行分辨率宽高比与画面输出宽高比不一致时，左侧大画面为了保持内容的完整性采用缩放方式处理，右侧小画面采用裁剪方式处理。
         - 画中画模板：适用于混合大小两路视频画面和其他用户混音，或者混合一路大画面和其他用户混音的场景。小画面悬浮于大画面之上，可以指定大小画面的用户以及小画面的显示位置。
-        - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。用户只发送音频，仍然会占用画面位置，显示背景。预设位置填满时，不再混合其他用户的画面和声音。
+        - 自定义模板：适用于在混流中指定用户的画面位置，或者预设视频画面位置的场景。当预设位置指定用户时，排版引擎会该用户预留位置；当预设位置未指定用户时，排版引擎会根据进房间顺序自动填充。预设位置填满时，不再混合其他用户的画面和声音。自定义模板启用占位图功能时（LayoutParams中的PlaceHolderMode设置成1），在预设位置的用户没有上行视频时可显示对应的占位图（PlaceImageId）。
 
         注意：2020年1月9号及以后创建的应用才能直接调用此接口。2020年1月9日之前创建的应用默认使用云直播的云端混流，如需切换至MCU混流，请[提交工单](https://console.cloud.tencent.com/workorder/category)寻求帮助。
 
-        :param request: Request instance for StartMCUMixTranscode.
-        :type request: :class:`tencentcloud.trtc.v20190722.models.StartMCUMixTranscodeRequest`
-        :rtype: :class:`tencentcloud.trtc.v20190722.models.StartMCUMixTranscodeResponse`
+        :param request: Request instance for StartMCUMixTranscodeByStrRoomId.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.StartMCUMixTranscodeByStrRoomIdRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.StartMCUMixTranscodeByStrRoomIdResponse`
 
         """
         try:
             params = request._serialize()
-            body = self.call("StartMCUMixTranscode", params)
+            body = self.call("StartMCUMixTranscodeByStrRoomId", params)
             response = json.loads(body)
             if "Error" not in response["Response"]:
-                model = models.StartMCUMixTranscodeResponse()
+                model = models.StartMCUMixTranscodeByStrRoomIdResponse()
                 model._deserialize(response["Response"])
                 return model
             else:
@@ -427,6 +629,34 @@ class TrtcClient(AbstractClient):
                 message = response["Response"]["Error"]["Message"]
                 reqid = response["Response"]["RequestId"]
                 raise TencentCloudSDKException(code, message, reqid)
+        except Exception as e:
+            if isinstance(e, TencentCloudSDKException):
+                raise
+            else:
+                raise TencentCloudSDKException(e.message, e.message)
+
+
+    def StopMCUMixTranscodeByStrRoomId(self, request):
+        """接口说明：结束云端混流
+
+        :param request: Request instance for StopMCUMixTranscodeByStrRoomId.
+        :type request: :class:`tencentcloud.trtc.v20190722.models.StopMCUMixTranscodeByStrRoomIdRequest`
+        :rtype: :class:`tencentcloud.trtc.v20190722.models.StopMCUMixTranscodeByStrRoomIdResponse`
+
+        """
+        try:
+            params = request._serialize()
+            body = self.call("StopMCUMixTranscodeByStrRoomId", params)
+            response = json.loads(body)
+            if "Error" not in response["Response"]:
+                model = models.StopMCUMixTranscodeByStrRoomIdResponse()
+                model._deserialize(response["Response"])
+                return model
+            else:
+                code = response["Response"]["Error"]["Code"]
+                message = response["Response"]["Error"]["Message"]
+                reqid = response["Response"]["RequestId"]
+                raise TencentCloudSDKException(code, message, reqid)
         except Exception as e:
             if isinstance(e, TencentCloudSDKException):
                 raise
